Learn R Programming

spflow (version 0.1.0)

expand_flow_neighborhood: Derive the flow neighborhood matrices

Description

Use the neighborhood matrices of origins and destinations to derive the three neighborhood matrices of the origin-destination flows. This function is used for simulations or for comparisons with the vectorized formulations of the model.

Usage

expand_flow_neighborhood(
  OW,
  DW,
  n_o = OW %|!|% nrow(OW),
  n_d = DW %|!|% nrow(DW),
  model = "model_9"
)

Arguments

OW

Origin neighborhood matrix

DW

Destination neighborhood matrix

n_o

A numeric indicating the number of origins

n_d

A numeric indicating the number of destinations

model

A character indicating the model identifier

See Also

Other spflow simulation functions: spatial_filter(), spflow_sim()