Learn R Programming

spflow (version 0.1.0)

mcmc_results: Access the sampling results of a spflow_model_mcmc-class()

Description

For details see the documentation of the corresponding class.

Usage

mcmc_results(object)

Arguments

Value

An mcmc object, containing the draws of the sampled parameters

See Also

spflow_model_mcmc-class()