Learn R Programming

spflow (version 0.1.0)

neighborhood: Generic for accessing the neighborhood matrix inside spflow network classes

Description

For details on the methods see the documentation of the corresponding classes.

Usage

neighborhood(object, ...)

neighborhood(object) <- value

Arguments

...

Arguments to be passed to methods

value

A neighborhood matrix to replace the existing one

Value

A matrix (optionally sparse), representing the neighborhood links betweem the nodes

See Also

sp_network_nodes-class() sp_multi_network-class()