Use the neighborhood matrices of origins and destinations to derive the three neighborhood matrices of the origin-destination flows. This function is used for simulations or for comparisons with the vectorized formulations of the model.
expand_flow_neighborhood(
OW,
DW,
n_o = OW %|!|% nrow(OW),
n_d = DW %|!|% nrow(DW),
model = "model_9"
)Origin neighborhood matrix
Destination neighborhood matrix
A numeric indicating the number of origins
A numeric indicating the number of destinations
A character indicating the model identifier
Other spflow simulation functions:
spatial_filter(),
spflow_sim()