powered by
spflow_model_mcmc-class()
For details see the documentation of the corresponding class.
mcmc_results(object)
A spflow_model_mcmc-class()
An mcmc object, containing the draws of the sampled parameters