Compute the moment expression in an interaction model in matrix form
moment_empirical_var(model_matrices, N, n_d, n_o)The moment (U'U) moment matrix is grouped into (4x4) blocks. These 16 blocks are derived as interactions from the four blocks alpha, alpha_I, beta, gamma. Only ten blocks are unique and the remaining six are inferred by symmetry. The developments follow the theory presented in Dargel2021;textualspflow.